.. _recipe_asr.formalpolarization:

asr.formalpolarization
======================


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.formalpolarization`-recipe.
This recipe is comprised of a single step, namely:

  - :py:func:`asr.formalpolarization.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.formalpolarization

or as a python module

.. code-block:: console

   $ python -m asr.formalpolarization

Detailed description
--------------------
Formal polarization phase.

Module for calculating formal polarization phase as defined in the
Modern Theory of Polarization. To learn more see more about this
please see our explanation of the :ref:`Modern theory of
polarization`, in particular to see the definition of the polarization
phase.

The central recipe of this module is :func:`asr.formalpolarization.main`.


Steps
-----


asr.formalpolarization
^^^^^^^^^^^^^^^^^^^^^^
.. autofunction:: asr.formalpolarization.main
   